==> oidc-1.0.0.tar.gz: oidc/src/Plugin/Validation/Constraint/UserMailUniqueValidator.php <==
<?php

namespace Drupal\oidc\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Validation\Plugin\Validation\Constraint\UniqueFieldValueValidator;
use Drupal\externalauth\AuthmapInterface;
use Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;

/**
 * Validator for the UserMailUnique constraint.
 */
class UserMailUniqueValidator extends UniqueFieldValueValidator implements ContainerInjectionInterface {

  /**
   * The authentication mapping service.
   *
   * @var \Drupal\externalauth\AuthmapInterface
   */
  protected $authmap;

  /**
   * The OpenID Connect realm manager.
   *
   * @var \Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManagerInterface
   */
  protected $realmManager;

  /**
   * Class constructor.
   *
   * @param \Drupal\externalauth\AuthmapInterface $authmap
   *   The authentication mapping service.
   * @param \Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManagerInterface $realm_manager
   *   The OpenID Connect realm manager.
   */
  public function __construct(AuthmapInterface $authmap, OpenidConnectRealmManager $realm_manager) {
    $this->authmap = $authmap;
    $this->realmManager = $realm_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('externalauth.authmap'),
      $container->get('plugin.manager.openid_connect_realm')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validate($items, Constraint $constraint) {
    /** @var \Drupal\user\UserInterface $user */
    $user = $items->getEntity();

    if (!$user->isNew()) {
      // Skip the validation for OpenID Connect users.
      $authmap = $this->authmap->getAll($user->id());

      foreach ($authmap as $provider => $authname) {
        if (strpos($provider, 'oidc:') !== 0) {
          continue;
        }

        $plugin_id = mb_substr($provider, 5);
        if ($this->realmManager->hasDefinition($plugin_id)) {
          return;
        }
      }
    }

    parent::validate($items, $constraint);
  }

}

==> oidc-2.2.0.tar.gz: oidc/src/Plugin/Validation/Constraint/UserMailUniqueValidator.php <==
<?php

namespace Drupal\oidc\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Validation\Plugin\Validation\Constraint\UniqueFieldValueValidator;
use Drupal\externalauth\AuthmapInterface;
use Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;

/**
 * Validator for the UserMailUnique constraint.
 */
class UserMailUniqueValidator extends UniqueFieldValueValidator implements ContainerInjectionInterface {

  /**
   * The authentication mapping service.
   *
   * @var \Drupal\externalauth\AuthmapInterface
   */
  protected $authmap;

  /**
   * The OpenID Connect realm manager.
   *
   * @var \Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManagerInterface
   */
  protected $realmManager;

  /**
   * Class constructor.
   *
   * @param \Drupal\externalauth\AuthmapInterface $authmap
   *   The authentication mapping service.
   * @param \Drupal\oidc\OpenidConnectRealm\OpenidConnectRealmManagerInterface $realm_manager
   *   The OpenID Connect realm manager.
   */
  public function __construct(AuthmapInterface $authmap, OpenidConnectRealmManagerInterface $realm_manager) {
    $this->authmap = $authmap;
    $this->realmManager = $realm_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('externalauth.authmap'),
      $container->get('plugin.manager.openid_connect_realm')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validate($items, Constraint $constraint) {
    /** @var \Drupal\user\UserInterface $user */
    $user = $items->getEntity();

    if (!$user->isNew()) {
      // Skip the validation for OpenID Connect users.
      $authmap = $this->authmap->getAll($user->id());

      foreach ($authmap as $provider => $authname) {
        if (strpos($provider, 'oidc:') !== 0) {
          continue;
        }

        $plugin_id = mb_substr($provider, 5);
        if ($this->realmManager->hasDefinition($plugin_id)) {
          return;
        }
      }
    }

    parent::validate($items, $constraint);
  }

}
